@@ -10,7 +10,7 @@ classifiers = [
  
 setup(
   name='Kittyscript',
-  version='2.9.5',
+  version='2.9.6',
   description='Assist mode for python',
   long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
   url='https://github.com/Iwertyuiop123653/kitty-script-',  
@@ -20,6 +20,6 @@ setup(
   classifiers=classifiers,
   keywords='Assist mode', 
   packages=find_packages(),
-  install_requires=['keyboard', 'qrcode', 'hashlib'],
+  install_requires=['keyboard', 'qrcode'],
   long_description_content_type='text/markdown'
 )
\ No newline at end of file
